@@ -39,6 +39,7 @@
 #include <lal/LALString.h>
 #include <lal/StringVector.h>
 #include <lal/Units.h>
+#include <lal/ConfigFile.h>
 
 // ---------- local defines
 
@@ -104,6 +105,17 @@ XLALCWMakeFakeMultiData ( MultiSFTVector **multiSFTs,			///< [out] pointer to op
       outMTS->length = numDet;
     } // if multiTseries
 
+  /* if no user-specified seed available,
+   * use system clock to get seed
+   * if we would leave it as NULL here and only set it from time() later in XLALCreateRandomParams(),
+   * all IFOs with X > 0 would always have a constant noise realization!
+   */
+  INT4 seed = dataParams->randSeed;
+  while ( seed == 0 ) {
+    REAL8 currenttime = XLALGetCPUTime();
+    seed = round(1e9*(currenttime-floor(currenttime))); // use fractional part only of XLALGetCPUTime() result, because seed must be an INT4 and overflows otherwise
+  }
+
   for ( UINT4 X=0; X < numDet; X ++ )
     {
       /* detector params */
@@ -116,7 +128,10 @@ XLALCWMakeFakeMultiData ( MultiSFTVector **multiSFTs,			///< [out] pointer to op
       mTimestamps.length = 1;
       mTimestamps.data = &(multiTimestamps->data[X]); // such that pointer mTimestamps.data[0] = multiTimestamps->data[X]
       dataParamsX.multiTimestamps = mTimestamps;
-      dataParamsX.randSeed = dataParams->randSeed + X;	// increase seed in deterministic way: allows comparison w mfd_v4 !!
+      /* increase seed in deterministic way: allows comparison w mfd_v4 !!
+       * this should be safe as long as the seed is 'randomized' e.g. by calling time()
+       */
+      dataParamsX.randSeed = seed + X;
 
       SFTVector **svp = NULL;
       REAL4TimeSeries **tsp = NULL;
@@ -281,7 +296,7 @@ XLALCWMakeFakeData ( SFTVector **SFTvect,
   REAL8 sqrtSn = dataParams->multiNoiseFloor.sqrtSn[0];
   if ( sqrtSn > 0)
     {
-      REAL8 noiseSigma = sqrtSn * sqrt ( fBand );
+      REAL8 noiseSigma = sqrtSn * sqrt ( 0.5 * fSamp );
       XLAL_CHECK ( XLALAddGaussianNoise ( Tseries_sum, noiseSigma, dataParams->randSeed ) == XLAL_SUCCESS, XLAL_EFUNC );
     }
 
@@ -640,7 +655,7 @@ XLALDestroyPulsarParams ( PulsarParams *params )
  */
 int
 XLALReadPulsarParams ( PulsarParams *pulsarParams,	///< [out] pulsar parameters to fill in from config string
-                       const LALParsedDataFile *cfgdata,///< [in] pre-parsed "SourceParamsIO" config-file contents
+                       LALParsedDataFile *cfgdata,      ///< [in] pre-parsed "SourceParamsIO" config-file contents
                        const CHAR *secName		///< [in] section-name to use from config-file string (can be NULL)
                        )
 {
@@ -697,15 +712,14 @@ XLALReadPulsarParams ( PulsarParams *pulsarParams,	///< [out] pulsar parameters
   // ---------- PulsarDopplerParams ----------
 
   // ----- refTime
-  REAL8 refTime_GPS = 0; BOOLEAN have_refTime;
-  XLAL_CHECK ( XLALReadConfigREAL8Variable ( &refTime_GPS, cfgdata, secName, "refTime", &have_refTime ) == XLAL_SUCCESS, XLAL_EFUNC );
+  LIGOTimeGPS refTime_GPS; BOOLEAN have_refTime;
+  XLAL_CHECK ( XLALReadConfigEPOCHVariable ( &refTime_GPS, cfgdata, secName, "refTime", &have_refTime ) == XLAL_SUCCESS, XLAL_EFUNC );
   XLAL_CHECK ( have_refTime, XLAL_EINVAL );
-
-  XLAL_CHECK ( XLALGPSSetREAL8 ( & pulsarParams->Doppler.refTime, refTime_GPS ) != NULL, XLAL_EFUNC );
+  pulsarParams->Doppler.refTime = refTime_GPS;
 
   // ----- Alpha
   REAL8 Alpha_Rad = 0; BOOLEAN have_Alpha;
-  XLAL_CHECK ( XLALReadConfigREAL8Variable ( &Alpha_Rad, cfgdata, secName, "Alpha", &have_Alpha ) == XLAL_SUCCESS, XLAL_EFUNC );
+  XLAL_CHECK ( XLALReadConfigRAJVariable ( &Alpha_Rad, cfgdata, secName, "Alpha", &have_Alpha ) == XLAL_SUCCESS, XLAL_EFUNC );
   XLAL_CHECK ( have_Alpha, XLAL_EINVAL );
 
   XLAL_CHECK ( (Alpha_Rad >= 0) && (Alpha_Rad < LAL_TWOPI), XLAL_EDOM );
@@ -713,7 +727,7 @@ XLALReadPulsarParams ( PulsarParams *pulsarParams,	///< [out] pulsar parameters
 
   // ----- Delta
   REAL8 Delta_Rad = 0; BOOLEAN have_Delta;
-  XLAL_CHECK ( XLALReadConfigREAL8Variable ( &Delta_Rad, cfgdata, secName, "Delta", &have_Delta ) == XLAL_SUCCESS, XLAL_EFUNC );
+  XLAL_CHECK ( XLALReadConfigDECJVariable ( &Delta_Rad, cfgdata, secName, "Delta", &have_Delta ) == XLAL_SUCCESS, XLAL_EFUNC );
   XLAL_CHECK ( have_Delta, XLAL_EINVAL );
 
   XLAL_CHECK ( (Delta_Rad >= -LAL_PI_2) && (Delta_Rad <= LAL_PI_2), XLAL_EDOM );
@@ -754,8 +768,8 @@ XLALReadPulsarParams ( PulsarParams *pulsarParams,	///< [out] pulsar parameters
   pulsarParams->Doppler.fkdot[6] = f6dot;
 
   // ----- orbit
-  REAL8 orbitTpSSB = 0;	BOOLEAN have_orbitTpSSB;
-  XLAL_CHECK ( XLALReadConfigREAL8Variable ( &orbitTpSSB, cfgdata, secName, "orbitTpSSB", &have_orbitTpSSB ) == XLAL_SUCCESS, XLAL_EFUNC );
+  LIGOTimeGPS orbitTp; BOOLEAN have_orbitTp;
+  XLAL_CHECK ( XLALReadConfigEPOCHVariable ( &orbitTp, cfgdata, secName, "orbitTp", &have_orbitTp ) == XLAL_SUCCESS, XLAL_EFUNC );
   REAL8 orbitArgp = 0; 	BOOLEAN have_orbitArgp;
   XLAL_CHECK ( XLALReadConfigREAL8Variable ( &orbitArgp, cfgdata, secName, "orbitArgp", &have_orbitArgp ) == XLAL_SUCCESS, XLAL_EFUNC );
   REAL8 orbitasini = 0 /* isolated pulsar */; BOOLEAN have_orbitasini;
@@ -765,14 +779,14 @@ XLALReadPulsarParams ( PulsarParams *pulsarParams,	///< [out] pulsar parameters
   REAL8 orbitPeriod = 0;BOOLEAN have_orbitPeriod;
   XLAL_CHECK ( XLALReadConfigREAL8Variable ( &orbitPeriod, cfgdata, secName, "orbitPeriod", &have_orbitPeriod ) == XLAL_SUCCESS, XLAL_EFUNC );
 
-  if ( have_orbitasini || have_orbitEcc || have_orbitPeriod || have_orbitArgp || have_orbitTpSSB )
+  if ( have_orbitasini || have_orbitEcc || have_orbitPeriod || have_orbitArgp || have_orbitTp )
     {
       XLAL_CHECK ( orbitasini >= 0, XLAL_EDOM );
-      XLAL_CHECK ( (orbitasini == 0) || ( have_orbitEcc && have_orbitPeriod && have_orbitArgp && have_orbitTpSSB ), XLAL_EINVAL );
+      XLAL_CHECK ( (orbitasini == 0) || ( have_orbitEcc && have_orbitPeriod && have_orbitArgp && have_orbitTp ), XLAL_EINVAL );
       XLAL_CHECK ( (orbitEcc >= 0) && (orbitEcc <= 1), XLAL_EDOM );
 
       /* fill in orbital parameter structure */
-      XLAL_CHECK ( XLALGPSSetREAL8 ( &(pulsarParams->Doppler.tp), orbitTpSSB ) != NULL, XLAL_EFUNC );
+      pulsarParams->Doppler.tp 		= orbitTp;
       pulsarParams->Doppler.argp 	= orbitArgp;
       pulsarParams->Doppler.asini 	= orbitasini;
       pulsarParams->Doppler.ecc 	= orbitEcc;
@@ -806,7 +820,7 @@ XLALReadPulsarParams ( PulsarParams *pulsarParams,	///< [out] pulsar parameters
       XLAL_CHECK ( transientTauDays > 0, XLAL_EDOM );
 
       pulsarParams->Transient.t0   = (UINT4) transientStartTime;
-      pulsarParams->Transient.tau  = (UINT4) ( transientTauDays * LAL_DAYSID_SI );
+      pulsarParams->Transient.tau  = (UINT4) ( transientTauDays * 86400 );
     } /* if transient window != none */
   else
     {
@@ -866,7 +880,7 @@ XLALPulsarParamsFromFile ( const char *fname 		///< [in] 'CWsources' config file
 /**
  * Function to determine the PulsarParamsVector input from a user-input defining CW sources.
  *
- * This option supports a dual-type feature: if the any string in the list is of the form '{...}', then
+ * This option supports a dual-type feature: if any string in the list is of the form '{...}', then
  * it determines the *contents* of a config-file, otherwise the name-pattern of config-files to be parsed by XLALFindFiles(),
  * NOTE: when specifying file-contents, options can be separated by ';' and/or newlines)
  */
