@@ -1,5 +1,5 @@
 //
-// Copyright (C) 2012, 2013, 2014 David Keitel, Bernd Machenschalk, Reinhard Prix, Karl Wette
+// Copyright (C) 2012--2014 David Keitel, Bernd Machenschalk, Reinhard Prix, Karl Wette
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -33,13 +33,13 @@ extern "C" {
 
 ///
 /// \defgroup ComputeFstat_h Header ComputeFstat.h
-/// \ingroup pkg_pulsarCoh
+/// \ingroup lalpulsar_coh
 /// \authors Badri Krishnan, Bernd Machenschalk, Chris Messenger, David Keitel, Holger Pletsch,
 ///          John T. Whelan, Karl Wette, Pinkesh Patel, Reinhard Prix, Xavier Siemens
 ///
 /// \brief The \f$\mathcal{F}\f$-statistic.
 ///
-/// This module provides a API for computing the \f$\mathcal{F}\f$-statistic \cite JKS98, using
+/// This module provides a API for computing the \f$\mathcal{F}\f$-statistic \cite JKS98 , using
 /// various different methods.  All data required to compute the \f$\mathcal{F}\f$-statistic are
 /// contained in the opaque structure \c FstatInput, which is shared by all methods. A function
 /// XLALCreateFstatInput() is provided for creating an \c FstatInput structure configured
@@ -100,58 +100,48 @@ typedef enum tagFstatQuantities {
 typedef enum tagFstatMethodType {
 
   /// \cond DONT_DOXYGEN
-  // Overall/demod start marker; set to 1 to allow range-check without warnings
-  FMETHOD_START = 1, FMETHOD_DEMOD_START = FMETHOD_START,
+  FMETHOD_START = 1,
   /// \endcond
 
   FMETHOD_DEMOD_GENERIC,	///< \a Demod: generic C hotloop, works for any number of Dirichlet kernel terms \f$\text{Dterms}\f$
   FMETHOD_DEMOD_OPTC,		///< \a Demod: gptimized C hotloop using Akos' algorithm, only works for \f$\text{Dterms} \lesssim 20\f$
-  FMETHOD_DEMOD_SSE,		///< \a Demod: SSE hotloop with precalc divisors, uses fixed \f$\text{Dterms} = 8\f$
   FMETHOD_DEMOD_ALTIVEC,	///< \a Demod: Altivec hotloop variant, uses fixed \f$\text{Dterms} = 8\f$
-
-  /// \cond DONT_DOXYGEN
-  // Demod end marker, resamp start marker
-  FMETHOD_DEMOD_END, FMETHOD_RESAMP_START = FMETHOD_DEMOD_END,
-  /// \endcond
+  FMETHOD_DEMOD_SSE,		///< \a Demod: SSE hotloop with precalc divisors, uses fixed \f$\text{Dterms} = 8\f$
+  FMETHOD_DEMOD_BEST,		///< \a Demod: best guess of the fastest available hotloop
 
   FMETHOD_RESAMP_GENERIC,	///< \a Resamp: generic implementation
+  FMETHOD_RESAMP_BEST,		///< \a Resamp: best guess of the fastest available implementation
 
   /// \cond DONT_DOXYGEN
-  // Resamp/overall end marker
-  FMETHOD_RESAMP_END, FMETHOD_END = FMETHOD_RESAMP_END
+  FMETHOD_END
   /// \endcond
 
 } FstatMethodType;
 
 ///
-/// Determine if #FstatMethodType value \c x belongs to the \a Demod class
+/// Struct of optional 'advanced level' and (potentially method-specific) arguments to be passed to the
+/// \f$\mathcal{F}\f$-statistic setup function XLALCreateFstatInput().
 ///
-#define XLALFstatMethodClassIsDemod(x)  ( ((x) > FMETHOD_DEMOD_START )  && ((x) < FMETHOD_DEMOD_END ) )
+typedef struct tagFstatOptionalArgs {
+  UINT4 randSeed;			///< Random-number seed value used in case of fake Gaussian noise generation (\c injectSqrtSX)
+  SSBprecision SSBprec;			///< Barycentric transformation precision.
+  UINT4 Dterms;                  	///< Number of Dirichlet kernel terms, used by some \a Demod methods; see #FstatMethodType.
+  UINT4 runningMedianWindow;	  	///< If SFT noise weights are calculated from the SFTs, the running median window length to use.
+  FstatMethodType FstatMethod;	  	///< Method to use for computing the \f$\mathcal{F}\f$-statistic.
+  PulsarParamsVector *injectSources;	///< Vector of parameters of CW signals to simulate and inject.
+  MultiNoiseFloor *injectSqrtSX;  	///< Single-sided PSD values for fake Gaussian noise to be added to SFT data.
+  MultiNoiseFloor *assumeSqrtSX;  	///< Single-sided PSD values to be used for computing SFT noise weights instead of from a running median of the SFTs themselves.
+  FstatInput *prevInput;		///< An \c FstatInput structure from a previous call to XLALCreateFstatInput(); may contain common workspace data than can be re-used to save memory.
+  FILE *timingLogFile;			///< Pointer to a file which might be used to log timing information by some \f$\mathcal{F}\f$-statistic methods.
+} FstatOptionalArgs;
+#ifdef SWIG // SWIG interface directives
+SWIGLAL(COPY_CONSTRUCTOR(tagFstatOptionalArgs));
+#endif // SWIG
 
 ///
-/// Determine if #FstatMethodType value \c x belongs to the \a Resamp class
+/// Global initializer for setting #FstatOptionalArgs to default values
 ///
-#define XLALFstatMethodClassIsResamp(x) ( ((x) > FMETHOD_RESAMP_START ) && ((x) < FMETHOD_RESAMP_END ) )
-
-///
-/// Provide a 'best guess' of the fastest available \a Demod method variant. Useful as a user default value.
-///
-extern const int FMETHOD_DEMOD_BEST;
-
-///
-/// Provide a 'best guess' of the fastest available \a Resamp method variant. Useful as a user default value.
-///
-extern const int FMETHOD_RESAMP_BEST;
-
-///
-/// Struct for collecting 'lower-level' tuning and method-specific parameters to be passed to the
-/// \f$\mathcal{F}\f$-statistic setup function.
-///
-typedef struct tagFstatExtraParams {
-  UINT4 randSeed;                 ///< Random-number seed value used for fake Gaussian noise generation.
-  SSBprecision SSBprec;           ///< Barycentric transformation precision.
-  UINT4 Dterms;                   ///< Number of Dirichlet kernel terms, used by some \a Demod methods; see #FstatMethodType
-} FstatExtraParams;
+extern const FstatOptionalArgs FstatOptionalArgsDefaults;
 
 ///
 /// An \f$\mathcal{F}\f$-statistic 'atom', i.e. the elementary per-SFT quantities required to compute the
@@ -255,7 +245,7 @@ typedef struct tagFstatResults {
   /// This array should not be accessed if #whatWasComputed & FSTATQ_PARTS_PER_DET is false.
 #ifdef SWIG // SWIG interface directives
   SWIGLAL(ARRAY_1D_PTR_1D(FstatResults, COMPLEX8, FaPerDet, UINT4, numDetectors, numFreqBins));
-  SWIGLAL(ARRAY_1D_PTR_1D(FstatResults, COMPLEX8, FaPerDet, UINT4, numDetectors, numFreqBins));
+  SWIGLAL(ARRAY_1D_PTR_1D(FstatResults, COMPLEX8, FbPerDet, UINT4, numDetectors, numFreqBins));
 #endif // SWIG
   COMPLEX8 *FaPerDet[PULSAR_MAX_DETECTORS];
   COMPLEX8 *FbPerDet[PULSAR_MAX_DETECTORS];
@@ -275,7 +265,6 @@ typedef struct tagFstatResults {
 } FstatResults;
 
 // ---------- API function prototypes ----------
-const CHAR *XLALGetFstatMethodName ( FstatMethodType i);
 int XLALFstatMethodIsAvailable ( FstatMethodType i );
 const CHAR *XLALFstatMethodHelpString ( void );
 int XLALParseFstatMethodString ( FstatMethodType *Fmethod, const char *s );
@@ -288,12 +277,10 @@ MultiFstatAtomVector* XLALCreateMultiFstatAtomVector ( const UINT4 length );
 void XLALDestroyMultiFstatAtomVector ( MultiFstatAtomVector *atoms );
 
 FstatInput *
-XLALCreateFstatInput ( const SFTCatalog *SFTcatalog, const REAL8 minCoverFreq, const REAL8 maxCoverFreq,
-                       const PulsarParamsVector *injectSources, const MultiNoiseFloor *injectSqrtSX,
-                       const MultiNoiseFloor *assumeSqrtSX, const UINT4 runningMedianWindow,
-                       const EphemerisData *ephemerides,
-                       const FstatMethodType FstatMethod, const FstatExtraParams *extraParams );
+XLALCreateFstatInput ( const SFTCatalog *SFTcatalog, const REAL8 minCoverFreq, const REAL8 maxCoverFreq, const REAL8 dFreq,
+                       const EphemerisData *ephemerides, const FstatOptionalArgs *optionalArgs );
 
+const CHAR *XLALGetFstatInputMethodName ( const FstatInput* input );
 const MultiLALDetector* XLALGetFstatInputDetectors ( const FstatInput* input );
 const MultiLIGOTimeGPSVector* XLALGetFstatInputTimestamps ( const FstatInput* input );
 const MultiNoiseWeights* XLALGetFstatInputNoiseWeights ( const FstatInput* input );
@@ -303,20 +290,13 @@ const MultiDetectorStateSeries* XLALGetFstatInputDetectorStates ( const FstatInp
 SWIGLAL(INOUT_STRUCTS(FstatResults**, Fstats));
 #endif
 int XLALComputeFstat ( FstatResults **Fstats, FstatInput *input, const PulsarDopplerParams *doppler,
-                       const REAL8 dFreq, const UINT4 numFreqBins, const FstatQuantities whatToCompute );
+                       const UINT4 numFreqBins, const FstatQuantities whatToCompute );
 
 void XLALDestroyFstatInput ( FstatInput* input );
 void XLALDestroyFstatResults ( FstatResults* Fstats );
 int XLALAdd4ToFstatResults ( FstatResults* Fstats );
 
-int XLALEstimatePulsarAmplitudeParams ( PulsarCandidate *pulsarParams, const LIGOTimeGPS* FaFb_refTime,
-                                        const COMPLEX8 Fa, const COMPLEX8 Fb, const AntennaPatternMatrix *Mmunu );
-
-int XLALAmplitudeParams2Vect ( PulsarAmplitudeVect A_Mu, const PulsarAmplitudeParams Amp );
-int XLALAmplitudeVect2Params( PulsarAmplitudeParams *Amp, const PulsarAmplitudeVect A_Mu );
-
 REAL4 XLALComputeFstatFromAtoms ( const MultiFstatAtomVector *multiFstatAtoms, const INT4 X );
-REAL4 XLALComputeFstatFromFaFb ( COMPLEX8 Fa, COMPLEX8 Fb, REAL4 A, REAL4 B, REAL4 C, REAL4 E, REAL4 Dinv );
 
 // @}
 
