@@ -170,23 +170,28 @@ typedef struct tagMetricEllipse {
 /*---------- external prototypes [API] ----------*/
 
 /* ------ functions to handle factored grids: 'sky x freq x f1dot...' covering ----- */
-void InitDopplerSkyScan(LALStatus *, DopplerSkyScanState *skyScan, const DopplerSkyScanInit *init);
+void XLALDestroyDopplerSkyScan ( DopplerSkyScanState *skyScan );
+int XLALInitDopplerSkyScan ( DopplerSkyScanState *skyScan, const DopplerSkyScanInit *init);
+
 int  XLALNextDopplerSkyPos( PulsarDopplerParams *pos, DopplerSkyScanState *skyScan);
-void FreeDopplerSkyScan(LALStatus *, DopplerSkyScanState *skyScan);
 
 void writeSkyGridFile(LALStatus *, const DopplerSkyGrid *grid, const CHAR *fname );
 
 /* ----- various utility functions ----- */
-void ParseSkyRegionString (LALStatus *, SkyRegion *region, const CHAR *input);
-void SkySquare2String (LALStatus *, CHAR **string, REAL8 Alpha, REAL8 Delta, REAL8 AlphaBand, REAL8 DeltaBand);
+CHAR *XLALSkySquare2String ( REAL8 Alpha, REAL8 Delta, REAL8 AlphaBand, REAL8 DeltaBand );
 
-void getMCDopplerCube (LALStatus *, DopplerRegion *cube, PulsarDopplerParams lal_signal, UINT4 PointsPerDim, const DopplerSkyScanInit *params);
+int XLALParseSkyRegionString ( SkyRegion *region, const CHAR *input);
 void getMetricEllipse(LALStatus *, MetricEllipse *ellipse, REAL8 mismatch, const REAL8Vector *metric, UINT4 dim0);
 
 int fprintfDopplerParams ( FILE *fp, const PulsarDopplerParams *params );
 
 DopplerSkyGrid *XLALEquiPartitionSkygrid ( const DopplerSkyGrid *skygrid, UINT4 jPart, UINT4 numPartitions );
 
+
+// ---------- deprecated LAL functions ----------
+void FreeDopplerSkyScan(LALStatus *, DopplerSkyScanState *skyScan);
+void InitDopplerSkyScan(LALStatus *, DopplerSkyScanState *skyScan, const DopplerSkyScanInit *init);
+
 #ifdef  __cplusplus
 }
 #endif
