@@ -25,7 +25,7 @@
  * \brief Computes quantities for amplitude demodulation.
  *
  * This routine computes the quantities \f$a(t)\f$ and \f$b(t)\f$ as defined in
- * Jaranowski, Krolak, and Schutz \cite JKS98, hereafter JKS.  These
+ * Jaranowski, Krolak, and Schutz \cite JKS98 , hereafter JKS.  These
  * functions quantify the dependence of the detector output on the
  * beam-pattern functions \f$F_{+}\f$ and \f$F_{\times}\f$; in fact, \f$a(t)\f$ and
  * \f$b(t)\f$ <i>are</i> the beam-pattern functions, without the dependence
@@ -53,7 +53,7 @@
 
 /*---------- INCLUDES ----------*/
 #include <lal/LALComputeAM.h>
-#include <lal/CWFastMath.h>
+#include <lal/SinCosLUT.h>
 
 /*---------- local DEFINES and macros ----------*/
 
@@ -847,13 +847,13 @@ XLALComputeMultiAMCoeffs ( const MultiDetectorStateSeries *multiDetStates, 	/**<
   /* prepare output vector */
   MultiAMCoeffs *ret;
   if ( ( ret = XLALCalloc( 1, sizeof( *ret ) )) == NULL ) {
-    XLALPrintError ("%s: failed to XLALCalloc( 1, %d)\n", __func__, sizeof( *ret ) );
+    XLALPrintError ("%s: failed to XLALCalloc( 1, %lu)\n", __func__, sizeof( *ret ) );
     XLAL_ERROR_NULL ( XLAL_ENOMEM );
   }
 
   ret->length = numDetectors;
   if ( ( ret->data = XLALCalloc ( numDetectors, sizeof ( *ret->data ) )) == NULL ) {
-    XLALPrintError ("%s: failed to XLALCalloc(%d, %d)\n", __func__, numDetectors, sizeof ( *ret->data ) );
+    XLALPrintError ("%s: failed to XLALCalloc(%d, %lu)\n", __func__, numDetectors, sizeof ( *ret->data ) );
     XLALFree ( ret );
     XLAL_ERROR_NULL ( XLAL_ENOMEM );
   }
@@ -893,7 +893,7 @@ XLALCreateAMCoeffs ( UINT4 numSteps )
   AMCoeffs *ret;
 
   if ( ( ret = XLALCalloc ( 1, sizeof (*ret) ) ) == NULL ) {
-    XLALPrintError ("%s: failed to XLALCalloc ( 1, %d )\n", __func__, sizeof (*ret) );
+    XLALPrintError ("%s: failed to XLALCalloc ( 1, %lu )\n", __func__, sizeof (*ret) );
     XLAL_ERROR_NULL ( XLAL_ENOMEM );
   }
 
