@@ -21,16 +21,16 @@
  * \author Matt Pitkin
  * \date 2013
  * \file
- * \ingroup pulsarTODO
+ * \ingroup lalpulsar_UNCLASSIFIED
  * \brief Functions to read TEMPO pulsar parameter files
  *
    Functions for reading pulsar parameters from TEMPO .par files.
 
-   \heading{Prototypes}
+   # Prototypes
 
 
 
-   \heading{Description}
+   # Description
 
    Radio astronomers fit pulsar parameters using TEMPO(2) which will output
    the parameters in a <tt>.par</tt> file. The values allowed in this file can be
@@ -52,20 +52,26 @@
    (as is given in the <tt>.par</tt> file) into a \c REAL8 value in
    radians.
 
-   \heading{Notes}
+   # Notes
 
 */
 
 #include <lal/ReadPulsarParFile.h>
 
+#include <config.h>
 #include <string.h>
 #include <math.h>
 #include <locale.h>
 #include <ctype.h>
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 #include <lal/LALConstants.h>
 #include <lal/LALStdlib.h>
 #include <lal/LALString.h>
 #include <lal/ComputeFstat.h>
+#include <lal/TranslateAngles.h>
+#include <lal/TranslateMJD.h>
 
 #ifdef __GNUC__
 #define UNUSED __attribute__ ((unused))
@@ -74,6 +80,8 @@
 #endif
 
 
+#define DAYSTOSECS 86400.0 /* number of seconds in an SI day */
+
 size_t PulsarTypeSize[5] = {
   sizeof(UINT4),
   sizeof(REAL8),
@@ -241,7 +249,6 @@ UINT4 *PulsarGetParamFitFlag( const PulsarParameters *pars, const CHAR *name ){
   if( !item ) { XLAL_ERROR_NULL( XLAL_EFAILED, "Entry \"%s\" not found.", name ); }
 
   if ( item->fitFlag == NULL ){ return NULL; }
-  //else { return ( *(UINT4 **)item->fitFlag ); }
   else { return item->fitFlag; }
 }
 
@@ -364,7 +371,7 @@ int PulsarCheckParam( PulsarParameters *pars, const CHAR *name ){
 
 void PulsarClearParams( PulsarParameters *pars ){
 /* Free all variables inside the linked list, leaving only the head struct */
-  PulsarParam *this, *next;
+  PulsarParam *this, *next = NULL;
 
   if( !pars ) { return; }
 
@@ -517,10 +524,10 @@ enum{
         else{ x *= convfactor; } \
       } \
       else if ( type == CONVHMS ) { /* convert to radians from hh:mm:ss.s format */ \
-        x = XLALhmsToRads( in ); \
+        XLALTranslateHMStoRAD( &x, in );                              \
       } \
       else if ( type == CONVDMS ) { /* convert to radians from hh:mm:ss.s format */ \
-        x = XLALdmsToRads( in ); \
+        XLALTranslateDMStoRAD( &x, in );                                  \
       } \
       else if ( type == CONVMJD ) { /* convert an MJD to a GPS time */ \
          x = XLALTTMJDtoGPS( atof(in) ); \
@@ -568,7 +575,7 @@ typedef struct tagParConversion{
 }ParConversion;
 
 
-#define NUM_PARS 94 /* number of allowed parameters */
+#define NUM_PARS 108 /* number of allowed parameters */
 
 /** Initialise conversion structure with most allowed TEMPO2 parameter names and conversion functions
  * (convert all read in parameters to SI units where necessary). See http://arxiv.org/abs/astro-ph/0603381 and
@@ -683,6 +690,7 @@ ParConversion pc[NUM_PARS] = {
   { .name = "PHI0", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* gravitational wave initial phase (radians) */
   { .name = "PSI", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* gravitational wave polarisation angle (radians) */
   { .name = "COSIOTA", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* cosine of source inclination angle */
+  { .name = "IOTA", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* the source inclination angle in radians */
   { .name = "C22", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* GW amplitude of C22 component */
   { .name = "C21", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* GW amplitude of C21 component */
   { .name = "PHI22", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* initial phase of C22 component (radians) */
@@ -690,8 +698,23 @@ ParConversion pc[NUM_PARS] = {
   { .name = "CGW", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* speed of gravitational waves as a fraction of the speed of light */
   { .name = "LAMBDA", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* parameters from http://uk.arxiv.org/abs/0909.4035 */
   { .name = "COSTHETA", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t },
+  { .name = "THETA", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t },
   { .name = "I21", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t },
-  { .name = "I31", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }
+  { .name = "I31", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t },
+
+  /* GW non-GR polarisation mode amplitude parameters */
+  { .name = "HPLUS", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* GW tensor plus polarisation amplitude */
+  { .name = "HCROSS", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* GW tensor cross polarisation amplitude */
+  { .name = "PSITENSOR", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* GW tensor angle polarisation */
+  { .name = "PHI0TENSOR", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* initial phase for tensor modes */
+  { .name = "HSCALARB", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* GW scalar breathing mode polarisation amplitude */
+  { .name = "HSCALARL", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* GW scalar longitudinal polarisation amplitude */
+  { .name = "PSISCALAR", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* GW scalar angle polarisation */
+  { .name = "PHI0SCALAR", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* initial phase for scalar modes */
+  { .name = "HVECTORX", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* GW vector x-mode amplitude */
+  { .name = "HVECTORY", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* GW vector y-mode amplitude */
+  { .name = "PSIVECTOR", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t }, /* GW vector angle polarisation */
+  { .name = "PHI0VECTOR", .convfunc = ParConvToFloat, .converrfunc = ParConvToFloat, .ptype = PULSARTYPE_REAL8_t } /* GW vector polarisation initial phase */
 };
 
 
@@ -943,22 +966,6 @@ PulsarParameters *XLALReadTEMPOParFileNew( const CHAR *pulsarAndPath ){
   return par;
 }
 
-
-void
-LALReadTEMPOParFile( LALStatus *status, BinaryPulsarParams *output, CHAR *pulsarAndPath ){
-  INITSTATUS(status);
-  ATTATCHSTATUSPTR(status);
-
-  ASSERT(output != (BinaryPulsarParams *)NULL, status,
-  READPULSARPARFILEH_ENULLOUTPUT, READPULSARPARFILEH_MSGENULLOUTPUT);
-
-  XLALReadTEMPOParFile( output, pulsarAndPath );
-
-  DETATCHSTATUSPTR(status);
-  RETURN(status);
-}
-
-
 /* NOTE: Convert this function to be more like readParfile.C in TEMPO2 - read
  * in a line at a time using fgets and make each parameter a structure */
 void
@@ -1142,6 +1149,7 @@ XLALReadTEMPOParFile( BinaryPulsarParams *output,
 
   output->h0=0.;
   output->cosiota=0.;
+  output->iota=0.;
   output->psi=0.;
   output->phi0=0.;
   output->Aplus=0.;
@@ -1150,13 +1158,28 @@ XLALReadTEMPOParFile( BinaryPulsarParams *output,
   output->I31=0.;
   output->lambda=0.;
   output->costheta=0.;
+  output->theta=0.;
   output->C22=0.;
   output->C21=0.;
   output->phi22=0.;
   output->phi21=0.;
 
+  output->hPlus=0.;
+  output->hCross=0.;
+  output->psiTensor=0.;
+  output->phi0Tensor=0.;
+  output->hScalarB=0.;
+  output->hScalarL=0.;
+  output->psiScalar=0.;
+  output->phi0Scalar=0.;
+  output->hVectorX=0.;
+  output->hVectorY=0.;
+  output->psiVector=0.;
+  output->phi0Vector=0.;
+
   output->h0Err=0.;
   output->cosiotaErr=0.;
+  output->iotaErr=0.;
   output->psiErr=0.;
   output->phi0Err=0.;
   output->AplusErr=0.;
@@ -1165,14 +1188,27 @@ XLALReadTEMPOParFile( BinaryPulsarParams *output,
   output->I31Err=0.;
   output->lambdaErr=0.;
   output->costhetaErr=0.;
+  output->thetaErr=0.;
   output->C22Err=0.;
   output->C21Err=0.;
   output->phi22Err=0.;
   output->phi21Err=0.;
+  output->hPlusErr=0.;
+  output->hCrossErr=0.;
+  output->psiTensorErr=0.;
+  output->phi0TensorErr=0.;
+  output->hScalarBErr=0.;
+  output->hScalarLErr=0.;
+  output->psiScalarErr=0.;
+  output->phi0ScalarErr=0.;
+  output->hVectorXErr=0.;
+  output->hVectorYErr=0.;
+  output->psiVectorErr=0.;
+  output->phi0VectorErr=0.;
 
   output->wave_omErr = 0.0;
 
-  output->cgw = 1.0; /* initialise the GW speed to be the speed of light */
+  output->cgw = 1.; /* initialise the GW speed to be the speed of light */
   output->cgwErr = 0.;
 
   output->units = NULL;
@@ -1227,7 +1263,7 @@ XLALReadTEMPOParFile( BinaryPulsarParams *output,
     }
     else if(!strcmp(val[i],"ra") || !strcmp(val[i],"RA") || !strcmp(val[i],"RAJ")){
       /* this can be in form hh:mm:ss.ss or hhmmss.ss */
-      output->ra = XLALhmsToRads(val[i+1]);
+      XLALTranslateHMStoRAD( &output->ra, val[i+1]);
       j++;
 
       /* only try to get error if one exists */
@@ -1238,7 +1274,7 @@ XLALReadTEMPOParFile( BinaryPulsarParams *output,
       }
     }
     else if(!strcmp(val[i],"dec") || !strcmp(val[i],"DEC") || !strcmp(val[i],"DECJ")) {
-      output->dec = XLALdmsToRads(val[i+1]);
+      XLALTranslateDMStoRAD ( &output->dec, val[i+1] );
       j++;
 
       if(atoi(val[i+2])==1 && i+2<k){
@@ -2003,6 +2039,15 @@ XLALReadTEMPOParFile( BinaryPulsarParams *output,
         j+=2;
       }
     }
+    else if( !strcmp(val[i],"iota") || !strcmp(val[i],"IOTA") ) {
+      output->iota = atof(val[i+1]);
+      j++;
+
+      if(atoi(val[i+2])==1 && i+2<k){
+        output->iotaErr = atof(val[i+3]);
+        j+=2;
+      }
+    }
     else if( !strcmp(val[i],"psi") || !strcmp(val[i],"PSI") ) {
       output->psi = atof(val[i+1]);
       j++;
@@ -2075,6 +2120,15 @@ XLALReadTEMPOParFile( BinaryPulsarParams *output,
         j+=2;
       }
     }
+    else if( !strcmp(val[i],"theta") || !strcmp(val[i],"THETA") ) {
+      output->theta = atof(val[i+1]);
+      j++;
+
+      if(atoi(val[i+2])==1 && i+2<k){
+        output->thetaErr = atof(val[i+3]);
+        j+=2;
+      }
+    }
     else if( !strcmp(val[i],"c22") || !strcmp(val[i],"C22") ) {
       output->C22 = atof(val[i+1]);
       j++;
@@ -2111,6 +2165,114 @@ XLALReadTEMPOParFile( BinaryPulsarParams *output,
         j+=2;
       }
     }
+    else if( !strcmp(val[i],"hplus") || !strcmp(val[i],"HPLUS") ) {
+      output->hPlus = atof(val[i+1]);
+      j++;
+
+      if(atoi(val[i+2])==1 && i+2<k){
+        output->hPlus = atof(val[i+3]);
+        j+=2;
+      }
+    }
+    else if( !strcmp(val[i],"hcross") || !strcmp(val[i],"HCROSS") ) {
+      output->hCross = atof(val[i+1]);
+      j++;
+
+      if(atoi(val[i+2])==1 && i+2<k){
+        output->hCrossErr = atof(val[i+3]);
+        j+=2;
+      }
+    }
+    else if( !strcmp(val[i],"psitensor") || !strcmp(val[i],"PSITENSOR") ) {
+      output->psiTensor = atof(val[i+1]);
+      j++;
+
+      if(atoi(val[i+2])==1 && i+2<k){
+        output->psiTensorErr = atof(val[i+3]);
+        j+=2;
+      }
+    }
+    else if( !strcmp(val[i],"phi0tensor") || !strcmp(val[i],"PHI0TENSOR") ) {
+      output->phi0Tensor = atof(val[i+1]);
+      j++;
+
+      if(atoi(val[i+2])==1 && i+2<k){
+        output->phi0TensorErr = atof(val[i+3]);
+        j+=2;
+      }
+    }
+    else if( !strcmp(val[i],"hscalarb") || !strcmp(val[i],"HSCALARB") ) {
+      output->hScalarB = atof(val[i+1]);
+      j++;
+
+      if(atoi(val[i+2])==1 && i+2<k){
+        output->hScalarBErr = atof(val[i+3]);
+        j+=2;
+      }
+    }
+    else if( !strcmp(val[i],"hscalarl") || !strcmp(val[i],"HSCALARL") ) {
+      output->hScalarL = atof(val[i+1]);
+      j++;
+
+      if(atoi(val[i+2])==1 && i+2<k){
+        output->hScalarLErr = atof(val[i+3]);
+        j+=2;
+      }
+    }
+    else if( !strcmp(val[i],"psiscalar") || !strcmp(val[i],"PSISCALAR") ) {
+      output->psiScalar = atof(val[i+1]);
+      j++;
+
+      if(atoi(val[i+2])==1 && i+2<k){
+        output->psiScalarErr = atof(val[i+3]);
+        j+=2;
+      }
+    }
+    else if( !strcmp(val[i],"phi0scalar") || !strcmp(val[i],"PHI0SCALAR") ) {
+      output->phi0Scalar = atof(val[i+1]);
+      j++;
+
+      if(atoi(val[i+2])==1 && i+2<k){
+        output->phi0ScalarErr = atof(val[i+3]);
+        j+=2;
+      }
+    }
+    else if( !strcmp(val[i],"hvectorx") || !strcmp(val[i],"HVECTORX") ) {
+      output->hVectorX = atof(val[i+1]);
+      j++;
+
+      if(atoi(val[i+2])==1 && i+2<k){
+        output->hVectorXErr = atof(val[i+3]);
+        j+=2;
+      }
+    }
+    else if( !strcmp(val[i],"hvectory") || !strcmp(val[i],"HVECTORY") ) {
+      output->hVectorY = atof(val[i+1]);
+      j++;
+
+      if(atoi(val[i+2])==1 && i+2<k){
+        output->hVectorYErr = atof(val[i+3]);
+        j+=2;
+      }
+    }
+    else if( !strcmp(val[i],"psivector") || !strcmp(val[i],"PSIVECTOR") ) {
+      output->psiVector = atof(val[i+1]);
+      j++;
+
+      if(atoi(val[i+2])==1 && i+2<k){
+        output->psiVectorErr = atof(val[i+3]);
+        j+=2;
+      }
+    }
+    else if( !strcmp(val[i],"phi0vector") || !strcmp(val[i],"PHI0VECTOR") ) {
+      output->phi0Vector = atof(val[i+1]);
+      j++;
+
+      if(atoi(val[i+2])==1 && i+2<k){
+        output->phi0VectorErr = atof(val[i+3]);
+        j+=2;
+      }
+    }
     else if( !strcmp(val[i],"cgw") || !strcmp(val[i],"CGW") ) {
       output->cgw = atof(val[i+1]);
       j++;
@@ -2315,159 +2477,6 @@ Parameters not in consistent order!\n");
 
   return params;
 }
-
-
-/* function to convert a string containing an angular coordinate in the format
- * degrees:minutues:seconds into radians */
-REAL8
-XLALdmsToRads( const CHAR *dms )
-{
-  XLAL_CHECK_REAL8( dms != NULL, XLAL_EIO, "Angle string is NULL" );
-
-  REAL8 s;
-  INT4 d, m;
-  int negbutzero = 0;
-  int numitems = sscanf(dms, "%d:%d:%lf", &d, &m, &s);
-
-  XLAL_CHECK_REAL8( numitems == 3, XLAL_EINVAL, "Angle string not in format 'degs:mins:secs'" );
-  XLAL_CHECK_REAL8( m >= 0 && m < 60, XLAL_EDOM, "Minutes is out of the 0 to 59 mins range" );
-  XLAL_CHECK_REAL8( s >= 0. && s < 60., XLAL_EDOM, "Seconds is out of the 0 to 60 secs range" );
-
-  /* check if the string is negative in the case when the degrees value is zero */
-  if( dms[0] == '-' && d == 0 ) { negbutzero = 1; }
-
-  /* if dec is negative convert mins and secs to -ve numbers */
-  if( d < 0 || negbutzero == 1 ){
-    m = -m;
-    s = -s;
-  }
-
-  /* convert from dd:mm:ss to radians */
-  const REAL8 deg2rad = LAL_PI_180;
-  REAL8 radians =  deg2rad * ( d + (m / 60.0) + (s / 3600.0) );
-
-  return radians;
-
-} // XLALdmsToRads()
-
-
-/* function to convert a string containing an angular coordinate in the format
- * hours:minutues:seconds into radians */
-REAL8
-XLALhmsToRads( const CHAR *hms )
-{
-  XLAL_CHECK_REAL8( hms != NULL, XLAL_EIO, "Angle string is NULL" );
-
-  REAL8 s;
-  INT4 h, m;
-  int numitems = sscanf(hms, "%d:%d:%lf", &h, &m, &s);
-
-  XLAL_CHECK_REAL8( numitems == 3, XLAL_EINVAL, "Angle string not in format 'hours:mins:secs'" );
-  XLAL_CHECK_REAL8( h >= 0 && h < 24, XLAL_EDOM, "Hours value must be within [0, 24)" );
-  XLAL_CHECK_REAL8( m >= 0 && m < 60, XLAL_EDOM, "Minutes is out of the 0 to 59 mins range" );
-  XLAL_CHECK_REAL8( s >= 0. && s < 60., XLAL_EDOM, "Seconds is out of the 0 to 60 secs range" );
-
-  /* convert from hh:mm:ss to radians */
-  const REAL8 hour2deg = 360./24.;
-  const REAL8 deg2rad  = LAL_PI_180;
-  const REAL8 hour2rad = hour2deg * deg2rad;
-
-  REAL8 radians = hour2rad * ( h + (m / 60.0) + (s / 3600.0) );
-
-  return radians;
-
-} // XLALhmsToRads()
-
-
-/* DEPREACTED: Use XLALhmsToRads() or XLALdmsToRads()
-   function converts dec or ra from format dd/hh:mm:ss.sss or format
-   dd/hhmmss.ss to radians */
-REAL8 LALDegsToRads(CHAR *degs, const CHAR *coord){
-  REAL8 radians=0.;
-  INT4 d, m;
-  REAL8 s;
-  CHAR dc[4]="", mc[3]="", *sc=NULL;
-  CHAR *loc;
-  INT4 n, negbutzero=0;
-
-  /* if in format dd/hh:mm:ss.s do this*/
-  /* locate first : */
-  if((loc = strchr(degs, ':'))!=NULL){
-    n = loc-degs;
-
-    /* copy degrees part to dc */
-    strncpy(dc, degs, n);
-    d = atoi(dc);
-
-    /* check if dec is negative but the degree part is zero */
-    if((strchr(degs, '-') != NULL) && d == 0){
-      negbutzero = 1;
-    }
-
-    /* copy minutes part to mc */
-    strncpy(mc, loc+1, 2);
-    m = atoi(mc);
-
-    /* copy seconds part to sc */
-    sc = XLALStringDuplicate(loc+4);
-    s = atof(sc);
-  }
-  /* if in format hh/ddmmss.ss */
-  else{
-    /* find pos of decimal point . (ascii character 46) */
-    loc = strchr(degs, '.');
-
-    /* get seconds part */
-    sc = XLALStringDuplicate(loc-2);
-    s = atof(sc);
-
-    /* get minutes part */
-    strncpy(mc, loc-4, 2);
-    m = atoi(mc);
-
-    /* get hours or degs part part */
-    /* check if first char is - (ascii character 45) */
-    if(strchr(degs, '-') != NULL){
-      /* first char is negative */
-      strncpy(dc, loc-7, 3);
-      d = atoi(dc);
-
-      /* if dec is negative but the degrees part is zero set flag */
-      negbutzero = 1;
-    }
-    else{
-      strncpy(dc, loc-6, 2);
-      d = atoi(dc);
-    }
-  }
-
-  if(strstr(coord, "ra") || strstr(coord, "RA") || strstr(coord, "alpha")){
-    /* convert from hh:mm:ss to radians */
-    radians = LAL_PI_180*(REAL8)d*(360.0/24.0);
-    radians += LAL_PI_180*((REAL8)m/60.0)*(360.0/24.0);
-    radians += LAL_PI_180*(s/(60.0*60.0))*(360.0/24.0);
-  }
-  else if(strstr(coord, "dec") || strstr(coord, "DEC") || strstr(coord, "delta")){
-    /* convert from dd:mm:ss to radians */
-    radians = LAL_PI_180*(REAL8)d;
-
-    /* if dec is negative convert mins and secs to -ve numbers */
-    if(d<0 || negbutzero==1){
-      m = -m;
-      s = -s;
-    }
-
-    radians += LAL_PI_180*(REAL8)m/60.0;
-    radians += LAL_PI_180*s/(60.0*60.0);
-  }
-
-  /* free mem */
-  XLALFree(sc);
-
-  return radians;
-}
-
-
 /* functions for converting times given in Terrestrial time TT or TDB in MJD to
 times in GPS - this is important for epochs given in .par files which are in
 TDB. TT and GPS are different by a factor of 51.184 secs, this is just the
@@ -2483,20 +2492,15 @@ and why they are necessary can be found in Seidelmann and Fukushima, A&A 265
 /** This function converts a MJD format time corrected to Terrestrial Time (TT)
  * into an equivalent GPS time */
 REAL8 XLALTTMJDtoGPS(REAL8 MJD){
-  REAL8 GPS;
 
-  /* Check not before the start of GPS time (MJD 44244) */
-  XLAL_CHECK_REAL8 ( MJD >= GPS0MJD, XLAL_EDOM, "Input MJD time %.1f is not in\
- range, must be > %.1f.\n", MJD, GPS0MJD);
+  LIGOTimeGPS GPS;
+  REAL8 mjdInt, mjdFrac;
+  mjdFrac = modf ( MJD, &mjdInt );
+  XLAL_CHECK_REAL8 ( XLALTranslateMJDTTtoGPS ( &GPS, (INT4)mjdInt, mjdFrac ) != NULL, XLAL_EFUNC );
 
-  /* there is the magical number factor of 32.184 + 19 leap seconds to the
-   * start of GPS time */
-  GPS = (MJD - GPS0MJD)*86400. - GPS_TDT;
-
-  return GPS;
+  return XLALGPSGetREAL8( &GPS );
 }
 
-
 /** If you have an MJD arrival time on the Earth then this will convert it to
  * the equivalent GPS time in TDB (see Table 1 of Seidelmann and Fukushima,
  * Astronomy & Astrophysics, 265, 833-838 (1992).
