@@ -922,7 +922,7 @@ LALReadSFTheader (LALStatus  *status,			/**< pointer to LALStatus structure */
   ASSERT (fname,  status, SFTFILEIO_ENULL,  SFTFILEIO_MSGENULL);
 
   /* opening the SFT binary file */
-  fp = LALOpenDataFile( fname );
+  fp = LALFopen( fname, "rb" );
   if (fp == NULL) {
     ABORT (status, SFTFILEIO_EFILE,  SFTFILEIO_MSGEFILE);
   }
@@ -1072,7 +1072,7 @@ LALReadSFTdata(LALStatus *status,			/**< pointer to LALStatus structure */
   offset = fminBinIndex - header.fminBinIndex;
 
   /* open file for reading */
-  if ( (fp = LALOpenDataFile( fname )) == NULL) {
+  if ( (fp = LALFopen( fname, "rb" )) == NULL) {
     ABORT (status, SFTFILEIO_EFILE, SFTFILEIO_MSGEFILE);
   }
 
@@ -1774,7 +1774,7 @@ read_v1_header_from_fp ( FILE *fp, SFTtype *header, UINT4 *nsamples, BOOLEAN swa
   /* double-check version-number */
   if ( rawheader.version != 1 )
     {
-      XLALPrintError ("\nWrong SFT-version %d in read_v1_header_from_fp()\n\n", rawheader.version );
+      XLALPrintError ("\nWrong SFT-version %g in read_v1_header_from_fp()\n\n", rawheader.version );
       goto failed;
     }
 
