@@ -67,14 +67,14 @@ XLALCreateSFT ( UINT4 numBins )
   SFTtype *sft;
 
   if ( (sft = XLALCalloc (1, sizeof(*sft) )) == NULL )
-    XLAL_ERROR_NULL ( XLAL_ENOMEM, "XLALCalloc (1, %d) failed.\n", sizeof(*sft) );
+    XLAL_ERROR_NULL ( XLAL_ENOMEM, "XLALCalloc (1, %lu) failed.\n", sizeof(*sft) );
 
   if ( numBins )
     {
       if ( (sft->data = XLALCreateCOMPLEX8Vector ( numBins )) == NULL )
         {
           XLALFree ( sft );
-          XLAL_ERROR_NULL ( XLAL_EFUNC, "XLALCreateCOMPLEX8Vector ( %s ) failed. xlalErrno = %d\n", numBins, xlalErrno );
+          XLAL_ERROR_NULL ( XLAL_EFUNC, "XLALCreateCOMPLEX8Vector ( %d ) failed. xlalErrno = %d\n", numBins, xlalErrno );
         }
     }
   else
@@ -267,6 +267,27 @@ XLALCreateTimestampVector ( UINT4 length )
 } /* XLALCreateTimestampVector() */
 
 
+/** Resize a LIGOTimeGPSVector */
+LIGOTimeGPSVector *
+XLALResizeTimestampVector ( LIGOTimeGPSVector *vector, UINT4 length )
+{
+  if ( ! vector ) { return XLALCreateTimestampVector( length ); }
+  if ( ! length ){
+    XLALDestroyTimestampVector( vector );
+    return NULL;
+  }
+
+  vector->data = XLALRealloc( vector->data, length * sizeof( LIGOTimeGPS ) );
+
+  if ( ! vector->data ) {
+    vector->length = 0;
+    XLAL_ERROR_NULL( XLAL_ENOMEM );
+  }
+  vector->length = length;
+  return vector;
+}
+
+
 /** De-allocate a LIGOTimeGPSVector */
 void
 XLALDestroyTimestampVector ( LIGOTimeGPSVector *vect)
@@ -411,12 +432,12 @@ XLALExtractMultiTimestampsFromSFTs ( const MultiSFTVector *multiSFTs )
   /* create output vector */
   MultiLIGOTimeGPSVector *ret = NULL;
   if ( (ret = XLALCalloc ( 1, sizeof(*ret) )) == NULL ) {
-    XLALPrintError ("%s: failed to XLALCalloc ( 1, %d ).\n", __func__, sizeof(*ret));
+    XLALPrintError ("%s: failed to XLALCalloc ( 1, %lu ).\n", __func__, sizeof(*ret));
     XLAL_ERROR_NULL ( XLAL_ENOMEM );
   }
 
   if ( (ret->data = XLALCalloc ( numIFOs, sizeof(*ret->data) )) == NULL ) {
-    XLALPrintError ("%s: failed to XLALCalloc ( %d, %d ).\n", __func__, numIFOs, sizeof(ret->data[0]) );
+    XLALPrintError ("%s: failed to XLALCalloc ( %d, %lu ).\n", __func__, numIFOs, sizeof(ret->data[0]) );
     XLALFree (ret);
     XLAL_ERROR_NULL ( XLAL_ENOMEM );
   }
@@ -469,7 +490,7 @@ XLALTimestampsFromSFTCatalog ( const SFTCatalog *catalog )		/**< [in] input SFT-
 
 /**
  * Extract timestamps-vector from a segment file, with functionality based on MakeSFTDAG
- * The filename should point to a file containing <GPSstart GPSend> of segments or <GPSstart GPSend segLength numSFTs> where segLength is in hours.
+ * The filename should point to a file containing \<GPSstart GPSend\> of segments or \<GPSstart GPSend segLength numSFTs\> where segLength is in hours.
  * adjustSegExtraTime is used in MakeSFTDAG to maximize the number of SFTs in each segement by placing the SFTs in the middle of the segment.
  * synchronize is used to force the start times of the SFTs to be integer multiples of Toverlap from the start time of the first SFT.
  * adjustSegExtraTime and synchronize cannot be used concurrently (synchronize will be preferred if both values are non-zero).
@@ -478,11 +499,12 @@ LIGOTimeGPSVector *
 XLALTimestampsFromSegmentFile ( const char *filename,    //!< filename: Input filename
                                 REAL8 Tsft,              //!< Tsft: SFT length of each timestamp, in seconds
                                 REAL8 Toverlap,          //!< Toverlap: time to overlap successive SFTs by, in seconds
-                                INT4 adjustSegExtraTime, //!< adjustSegExtraTime: (0 or 1) remove the unused time from beginning and end of the segments (see MakeSFTDAG)
-                                INT4 synchronize         //!< synchronize: (0 or 1) synchronize SFT start times according to the start time of the first SFT
+                                BOOLEAN adjustSegExtraTime, //!< adjustSegExtraTime: remove the unused time from beginning and end of the segments (see MakeSFTDAG)
+                                BOOLEAN synchronize         //!< synchronize: synchronize SFT start times according to the start time of the first SFT. Start time of first SFT is shifted to next higher integer value of Tsft
                                 )
 {
   XLAL_CHECK_NULL ( filename != NULL, XLAL_EINVAL );
+  XLAL_CHECK_NULL ( !(adjustSegExtraTime && synchronize), XLAL_EINVAL, "Must specify only one of adjustSegExtraTime or synchronize" );
 
   LALSegList *list = NULL;
   XLAL_CHECK_NULL ( ( list = XLALReadSegmentsFromFile ( filename )) != NULL, XLAL_EFUNC );
@@ -526,7 +548,7 @@ XLALTimestampsFromSegmentFile ( const char *filename,    //!< filename: Input fi
           REAL8 segStartTime = XLALGPSGetREAL8 ( &(list->segs[i].start) );
           REAL8 segEndTime = XLALGPSGetREAL8 ( &(list->segs[i].end) );
           if ( firstSFTstartTime==0.0 ) {
-            firstSFTstartTime = segStartTime;
+             firstSFTstartTime = ceil(segStartTime/Tsft)*Tsft;
           }
           analysisStartTime = round ( ceil ( (segStartTime - firstSFTstartTime)/((1.0 - overlapFraction)*Tsft))*(1.0 - overlapFraction)*Tsft) + firstSFTstartTime;
           if (analysisStartTime > segEndTime) {
@@ -602,7 +624,7 @@ XLALTimestampsFromSegmentFile ( const char *filename,    //!< filename: Input fi
           REAL8 segStartTime = XLALGPSGetREAL8 ( &(list->segs[i].start) );
           REAL8 segEndTime = XLALGPSGetREAL8 ( &(list->segs[i].end) );
           if ( firstSFTstartTime==0.0 ) {
-            firstSFTstartTime = segStartTime;
+             firstSFTstartTime = ceil(segStartTime/Tsft)*Tsft;
           }
           analysisStartTime = round ( ceil ( (segStartTime - firstSFTstartTime)/((1.0 - overlapFraction)*Tsft))*(1.0 - overlapFraction)*Tsft) + firstSFTstartTime;
           if (analysisStartTime > segEndTime) {
@@ -630,14 +652,16 @@ XLALTimestampsFromSegmentFile ( const char *filename,    //!< filename: Input fi
           }
           if ( endTime <= analysisEndTime ) {
             numThisSeg++;
+            LIGOTimeGPS sftStart;
+            XLALGPSSetREAL8( &sftStart, endTime-Tsft);
+            ret->data[j] = sftStart;
+            j++;
           }
-          LIGOTimeGPS sftStart;
-          XLALGPSSetREAL8( &sftStart, endTime-Tsft);
-          ret->data[j] = sftStart;
-          j++;
         } // while ( endTime < analysisEndTime )
     } // for i < length
 
+  XLALSegListFree(list);
+
   /* done: return Ts-vector */
   return ret;
 
@@ -1494,7 +1518,7 @@ XLALSFTAdd ( SFTtype *a,		/**< [in/out] SFT to be added to */
   XLAL_CHECK ( a->data != NULL, XLAL_EINVAL );
   XLAL_CHECK ( b->data != NULL, XLAL_EINVAL );
 
-  XLAL_CHECK ( XLALGPSDiff ( &(a->epoch), &(b->epoch) ) == 0, XLAL_EINVAL, "SFT epochs differ %ld != %ld ns\n", XLALGPSToINT8NS ( &(a->epoch) ), XLALGPSToINT8NS ( &(b->epoch) ) );
+  XLAL_CHECK ( XLALGPSDiff ( &(a->epoch), &(b->epoch) ) == 0, XLAL_EINVAL, "SFT epochs differ %"LAL_INT8_FORMAT" != %"LAL_INT8_FORMAT" ns\n", XLALGPSToINT8NS ( &(a->epoch) ), XLALGPSToINT8NS ( &(b->epoch) ) );
 
   REAL8 tol = 10 * LAL_REAL8_EPS;	// generously allow up to 10*eps tolerance
   XLAL_CHECK ( gsl_fcmp ( a->f0, b->f0, tol ) == 0, XLAL_ETOL, "SFT frequencies relative deviation exceeds %g: %.16g != %.16g\n", tol, a->f0, b->f0 );
